'use strict';

var FS              = require('fs');
var router          = require('./server-routes/router');
var indexHTML       = FS.readFileSync('index.html', { encoding: 'utf-8' });

function ApiGatewayError (error) {
  error = error || {};
  var statusCode = error.statusCode || 500;
  var statusMessage = error.statusMessage || error.description || '';

  this.message = statusCode + ' ' + statusMessage;
  this.name = error.html || error.location;
}
ApiGatewayError.prototype = new Error();

exports.handler = function(event, context, callback) {
  context.callbackWaitsForEmptyEventLoop = false;

  var matches = router.recognize(event.path);

  if(matches) {
    var handler = matches[0].handler;
    var params = matches[0].params;

    return handler(params)
      .then(function(html) { callback(null, indexHTML); })
      .catch(function(err) { callback(new ApiGatewayError(err)); });
  } else {
    return callback(new ApiGatewayError({ statusCode: 404 }));
  }
}
